@@ -19,10 +19,10 @@
 # along with this program. If not, see http://www.gnu.org/licenses/.
 #------------------------------------------------------------------------------
 
-try:
-  __import__('pkg_resources').declare_namespace(__name__)
-except ImportError:
-  __path__ = __import__('pkgutil').extend_path(__path__, __name__)
+# try:
+#   __import__('pkg_resources').declare_namespace(__name__)
+# except ImportError:
+#   __path__ = __import__('pkgutil').extend_path(__path__, __name__)
 
 #------------------------------------------------------------------------------
 # end of $Id$
