@@ -1,15 +1,28 @@
 # -*- coding: utf-8 -*-
 #------------------------------------------------------------------------------
 # file: $Id$
-# lib:  svnpublish.engine
-# desc: exports an svn repository to a filesystem
-# auth: griffin <griffin@uberdev.org>
+# auth: metagriffin <mg.github@uberdev.org>
 # date: 2009/09/02
-# copy: (C) CopyLoose 2009 UberDev <hardcore@uberdev.org>, No Rights Reserved.
+# copy: (C) Copyright 2009-EOT metagriffin -- see LICENSE.txt
+#------------------------------------------------------------------------------
+# This software is free software: you can redistribute it and/or
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# This software is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+# General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see http://www.gnu.org/licenses/.
+#------------------------------------------------------------------------------
+
 #------------------------------------------------------------------------------
 # TODO: why not pass *ALL* config variables through a generic evalVars()?
-#      the easiest way to do that would be to convert the config object to
-#      a class...
+#       the easiest way to do that would be to convert the config object to
+#       a class...
 #------------------------------------------------------------------------------
 
 import sys, os, os.path, re, hashlib, logging
@@ -201,10 +214,11 @@ def run_engines(params, paramkey, engtype, args=None,
         params.logger.debug('engine "%s" does not support dry-run mode - skipping', engine)
         continue
     engine_params = aadict(params).update(engcfg).update({
-      'logger': logging.getLogger('.'.join((params.logger.name, engtype, engine))),
-      'prefix': prefix,
-      'env': engine_env,
-      'evals': evals,
+      'options' : engcfg,
+      'logger'  : logging.getLogger('.'.join((params.logger.name, engtype, engine))),
+      'prefix'  : prefix,
+      'env'     : engine_env,
+      'evals'   : evals,
       })
     handler(engine_params, *args)
 
